CCL: /home/chisarie/Documents/lsst_ccl/CCL/src/ccl_neutrinos.c File Reference

CCL

Functions | Variables
ccl_neutrinos.c File Reference
`#include "ccl_neutrinos.h"`
`#include "ccl_utils.h"`
`#include "ccl_constants.h"`
`#include "gsl/gsl_errno.h"`
`#include "gsl/gsl_spline.h"`
`#include "gsl/gsl_integration.h"`
`#include "gsl/gsl_const_mksa.h"`
`#include "ccl_error.h"`
`#include "ccl_core.h"`

## Functions
gsl_spline * | calculate_nu_phasespace_spline (int *status)
double | nu_phasespace_intg (gsl_interp_accel *accel, double mnuOT, int *status)
double | Omeganuh2 (double a, double Neff, double mnu, double TCMB, gsl_interp_accel *accel, int *status)

## Variables
gsl_spline * | nu_spline =NULL

## Function Documentation

## ◆ calculate_nu_phasespace_spline()

gsl_spline* calculate_nu_phasespace_spline | ( | int * | status | ) |

Spline for the phasespace integral required for getting the fractional energy density of massive neutrinos. Returns a gsl spline for the phase space integral needed for massive neutrinos.

Parameters

  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  spl, the gsl spline for the phasespace integral required for massive neutrino calculations.

## ◆ nu_phasespace_intg()

double nu_phasespace_intg | ( | gsl_interp_accel * | accel,
|  | double | mnuOT,
|  | int * | status
| ) |  |

## ◆ Omeganuh2()

double Omeganuh2 | ( | double | a,
|  | double | Neff,
|  | double | mnu,
|  | double | TCMB,
|  | gsl_interp_accel * | accel,
|  | int * | status
| ) |  |

Returns density of one neutrino species at a scale factor a. Users are encouraged to access this quantity via the function ccl_omega_x.

Parameters

  a | Scale factor
  Neff | The effective number of species with neutrino mass mnu.
  mnu | Neutrino mass (can be 0).
  TCMB | Temperature of the CMB
  accel | - Interpolation accelerator to be used with phasespace spline. If not set yet, pass NULL.
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  OmNuh2 Fractional energy density of neutrions with mass mnu, multiplied by h squared.

## Variable Documentation

## ◆ nu_spline

gsl_spline* nu_spline =NULL